@@ -1,7 +1,7 @@
 package Monitoring::Icinga2::Client::Simple;
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_04'; # TRIAL
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_05'; # TRIAL
 
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100004';use strict;
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100005';use strict;
 use warnings;
 use 5.010_001;
 use Monitoring::Icinga2::Client::REST 2;
@@ -32,7 +32,7 @@ sub new {
 sub schedule_downtime {
     my ($self, %args) = @_;
     _checkargs(\%args, qw/ start_time end_time comment host /);
-    # uncoverable condition false
+    # uncoverable condition true
     $args{author} //= getlogin;
 
     if( $args{service} and not $args{services} ) {
@@ -122,7 +122,7 @@ sub set_notifications {
     my $uri_object = $args{service} ? 'services' : 'hosts';
 
     return $self->_verbose_request('POST',
-        "/objects/$uri_object/",
+        "/objects/$uri_object",
         {
             attrs => { enable_notifications => !!$args{state} },
             filter => _create_filter( \%args ),
@@ -180,6 +180,33 @@ sub set_global_notifications {
     $self->set_app_attrs( notifications => $state );
 }
 
+sub query_host {
+    my ($self, %args) = @_;
+    _checkargs(\%args, qw/ host /);
+    return $self->_verbose_request('GET',
+        '/objects/hosts',
+        { filter => "host.name==\"$args{host}\"" }
+    )->[0];
+}
+
+sub query_child_hosts {
+    my ($self, %args) = @_;
+    _checkargs(\%args, qw/ host /);
+    return $self->_verbose_request('GET',
+        '/objects/hosts',
+        { filter => "\"$args{host}\" in host.vars.parents" }
+    );
+}
+
+sub query_services {
+    my ($self, %args) = @_;
+    _checkargs(\%args, qw/ service /);
+    return $self->_verbose_request('GET',
+        '/objects/services',
+        { filter => "service.name==\"$args{service}\"" }
+    );
+}
+
 sub _verbose_request {
     my ($self, $method, $url, $getargs, $postdata) = @_;
 
@@ -243,6 +270,8 @@ sub _debug_dump {
 
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -253,7 +282,7 @@ Monitoring::Icinga2::Client::Simple
 
 =head1 VERSION
 
-version 0.001000_04
+version 0.001000_05
 
 =head1 DESCRIPTION
 
@@ -438,17 +467,40 @@ If C<host> or both C<host> and C<service> are used, I<all> downtimes on these
 objects are deleted. Set C<services> to a true value and pass a C<host>
 argument to also delete all of this host's service downtimes.
 
+=head2 query_host
+
+    $result = $ia->query_host( host => 'web-1' );
+    say "$result->{attrs}{name}: $result->{attrs}{type}";
+
+Query all information Icinga2 has on a certain host. The result is a hashref,
+currently containing a single key C<attrs>. If the host is not found, C<undef>
+is eturned.
+
+The only mandatory argument is C<host>.
+
 =head2 query_child_hosts
 
     $results = $ia->query_child_hosts( host => 'hypervisor-1' );
-    say "$_->{name}: $_->{type}" for @$results;
+    say "$_->{attrs}{name}: $_->{attrs}{type}" for @$results;
 
 Query all host objects that have a certain host listed as a parent. The result
-is a reference to a list of rather large hashes containing all the object
-attributes, of which C<name> will probably be most relevant.
+is a reference to a list of hashes like those returned by L</query_host>.
 
 The only mandatory argument is C<host>.
 
+=head2 query_services
+
+    $result = $ia->query_services( service => 'HTTP' );
+    say "$_->{attrs}{name}: $_->{attrs}{type}" for @$results;
+
+Query all information Icinga2 has on a certain service. As services usually
+have more than one instance, the result is a reference to a list of hashes,
+each describing one instance.
+
+The only mandatory argument is C<service>. Note that this is a singular as it
+specifies a single service name while the method name is plural due to the
+plurality of returned results.
+
 =head2 send_custom_notification
 
     $ia->send_custom_notification( comment => 'Just kidding :)', service => 'HTTP' );
@@ -551,20 +603,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__END__
-
-
-sub query_child_hosts {
-    my ($self, %args) = @_;
-    _checkargs(\%args, qw/ host /);
-
-    return $self->_verbose_request('GET',
-        '/objects/hosts',
-        {
-            filter => "\"$args{host}\" in host.vars.parents",
-        }
-    );
-}
-
-
